import { AUTH_HEADER, AUTH_TOKEN } from "../../../base";
import { decrypt } from "../../utils/utils";
export class FetchHttpClient {
  /**
   * Singleton class private contructor
   */
  constructor() { }
  /**
   * Singleton class create instance
   */
  static getInstance() {
    if (!FetchHttpClient.instance) {
      FetchHttpClient.instance = new FetchHttpClient();
      FetchHttpClient.token = FetchHttpClient.instance.getAuthToken();
    }
    return FetchHttpClient.instance;
  }
  /**
   * Get auth token
   *
   * @returns string | null
   */
  getAuthToken() {
    if (AUTH_TOKEN) {
      let ltoken = localStorage.getItem(AUTH_TOKEN);
      if (ltoken && ltoken != "") {
        return decrypt(JSON.parse(ltoken));
      }
      return "";
    }
    return "";
  }
  ;
  /**
   * Post request
   * @param params
   * @returns
   */
  async post(params) {
    let response;
    try {
      response = await fetch(params.url, {
        method: 'POST',
        body: JSON.stringify(params.body),
        headers: this.prepareAuthHeader(params.headers)
      });
    }
    catch (error) {
      response = error.json();
    }
    return response.json();
  }
  async put(params) {
    let response;
    try {
      response = await fetch(params.url, {
        method: 'PUT',
        body: JSON.stringify(params.body),
        headers: this.prepareAuthHeader(params.headers)
      });
    }
    catch (error) {
      response = error.json();
    }
    return response.json();
  }
  async get(params) {
    let response;
    try {
      response = await fetch(params.url + new URLSearchParams(params.query), {
        headers: this.prepareAuthHeader(params.headers)
      });
    }
    catch (error) {
      response = error.json();
    }
    return response.json();
  }
  /**
   * Prepare auth headers
   *
   * @param headers
   * @returns
   */
  prepareAuthHeader(headers) {
    if (!FetchHttpClient.token)
      FetchHttpClient.token = FetchHttpClient.instance.getAuthToken();
    if (headers && FetchHttpClient.token && FetchHttpClient.token != "")
      headers[AUTH_HEADER] = FetchHttpClient.token;
    return headers;
  }
}
